Exception: Acta::TruncateOrderError

Inherits:
Error
  • Object
show all
Defined in:
lib/acta/errors.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(projections) ⇒ TruncateOrderError

Returns a new instance of TruncateOrderError.



78
79
80
81
82
83
84
85
# File 'lib/acta/errors.rb', line 78

def initialize(projections)
  @projections = projections
  super(
    "Cannot determine a safe truncate order for projections #{projections.map(&:name).inspect}" \
    "their declared `truncates` classes form a foreign-key cycle. " \
    "Either break the cycle or have one projection truncate the other's tables itself."
  )
end

Instance Attribute Details

#projectionsObject (readonly)

Returns the value of attribute projections.



76
77
78
# File 'lib/acta/errors.rb', line 76

def projections
  @projections
end